"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AtGroupType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AtGroupTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AtGroupType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AT_GROUP_TYPE_DEFAULT: _AtGroupType.ValueType  # 0
    """默认"""
    AT_GROUP_TYPE_RECENT: _AtGroupType.ValueType  # 1
    """最近联系"""
    AT_GROUP_TYPE_FOLLOW: _AtGroupType.ValueType  # 2
    """我的关注（互相关注 > 单向关注）"""
    AT_GROUP_TYPE_FANS: _AtGroupType.ValueType  # 3
    """我的粉丝"""
    AT_GROUP_TYPE_OTHERS: _AtGroupType.ValueType  # 4
    """其他"""

class AtGroupType(_AtGroupType, metaclass=_AtGroupTypeEnumTypeWrapper):
    """at分组类型"""

AT_GROUP_TYPE_DEFAULT: AtGroupType.ValueType  # 0
"""默认"""
AT_GROUP_TYPE_RECENT: AtGroupType.ValueType  # 1
"""最近联系"""
AT_GROUP_TYPE_FOLLOW: AtGroupType.ValueType  # 2
"""我的关注（互相关注 > 单向关注）"""
AT_GROUP_TYPE_FANS: AtGroupType.ValueType  # 3
"""我的粉丝"""
AT_GROUP_TYPE_OTHERS: AtGroupType.ValueType  # 4
"""其他"""
global___AtGroupType = AtGroupType

class _AttachCardType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AttachCardTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AttachCardType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ATTACH_CARD_NONE: _AttachCardType.ValueType  # 0
    """无"""
    ATTACH_CARD_GOODS: _AttachCardType.ValueType  # 1
    """商品卡"""
    ATTACH_CARD_VOTE: _AttachCardType.ValueType  # 2
    """投票卡"""
    ATTACH_CARD_UGC: _AttachCardType.ValueType  # 3
    """ugc视频卡"""
    ATTACH_CARD_ACTIVITY: _AttachCardType.ValueType  # 4
    """帮推"""
    ATTACH_CARD_OFFICIAL_ACTIVITY: _AttachCardType.ValueType  # 5
    """官方活动"""
    ATTACH_CARD_TOPIC: _AttachCardType.ValueType  # 6
    """话题活动"""
    ATTACH_CARD_OGV: _AttachCardType.ValueType  # 7
    """OGV"""
    ATTACH_CARD_AUTO_OGV: _AttachCardType.ValueType  # 8
    """OGV自动出卡"""
    ATTACH_CARD_GAME: _AttachCardType.ValueType  # 9
    """游戏"""
    ATTACH_CARD_MANGA: _AttachCardType.ValueType  # 10
    """漫画"""
    ATTACH_CARD_DECORATION: _AttachCardType.ValueType  # 11
    """装扮"""
    ATTACH_CARD_MATCH: _AttachCardType.ValueType  # 12
    """赛事"""
    ATTACH_CARD_PUGV: _AttachCardType.ValueType  # 13
    """课程"""
    ATTACH_CARD_RESERVE: _AttachCardType.ValueType  # 14
    """预约"""
    ATTACH_CARD_UP_TOPIC: _AttachCardType.ValueType  # 15
    """up主话题活动"""

class AttachCardType(_AttachCardType, metaclass=_AttachCardTypeEnumTypeWrapper):
    """"""

ATTACH_CARD_NONE: AttachCardType.ValueType  # 0
"""无"""
ATTACH_CARD_GOODS: AttachCardType.ValueType  # 1
"""商品卡"""
ATTACH_CARD_VOTE: AttachCardType.ValueType  # 2
"""投票卡"""
ATTACH_CARD_UGC: AttachCardType.ValueType  # 3
"""ugc视频卡"""
ATTACH_CARD_ACTIVITY: AttachCardType.ValueType  # 4
"""帮推"""
ATTACH_CARD_OFFICIAL_ACTIVITY: AttachCardType.ValueType  # 5
"""官方活动"""
ATTACH_CARD_TOPIC: AttachCardType.ValueType  # 6
"""话题活动"""
ATTACH_CARD_OGV: AttachCardType.ValueType  # 7
"""OGV"""
ATTACH_CARD_AUTO_OGV: AttachCardType.ValueType  # 8
"""OGV自动出卡"""
ATTACH_CARD_GAME: AttachCardType.ValueType  # 9
"""游戏"""
ATTACH_CARD_MANGA: AttachCardType.ValueType  # 10
"""漫画"""
ATTACH_CARD_DECORATION: AttachCardType.ValueType  # 11
"""装扮"""
ATTACH_CARD_MATCH: AttachCardType.ValueType  # 12
"""赛事"""
ATTACH_CARD_PUGV: AttachCardType.ValueType  # 13
"""课程"""
ATTACH_CARD_RESERVE: AttachCardType.ValueType  # 14
"""预约"""
ATTACH_CARD_UP_TOPIC: AttachCardType.ValueType  # 15
"""up主话题活动"""
global___AttachCardType = AttachCardType

class _ContentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ContentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ContentType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CONTENT_TYPE_NONE: _ContentType.ValueType  # 0
    """占位"""
    TEXT: _ContentType.ValueType  # 1
    """文本，简单内容，biz_id就是文本"""
    AT: _ContentType.ValueType  # 2
    """@用户，简单内容，biz_id是用户uid"""
    LOTTERY: _ContentType.ValueType  # 3
    """抽奖，简单内容，biz_id是抽奖id"""
    VOTE: _ContentType.ValueType  # 4
    """投票，简单内容，biz_id是投票id"""
    TOPIC: _ContentType.ValueType  # 5
    """话题，简单内容，biz_id是话题id"""
    GOODS: _ContentType.ValueType  # 6
    """商品文字链，复杂内容，定义在GoodsContent结构，biz_id为空"""
    BV: _ContentType.ValueType  # 7
    """bv，简单内容，biz_id是bvid，包括"BV1"等内容"""
    AV: _ContentType.ValueType  # 8
    """av，简单内容，biz_id是avid"""
    EMOJI: _ContentType.ValueType  # 9
    """表情，简单内容，biz_id为空"""
    USER: _ContentType.ValueType  # 10
    """外露用户，暂未使用"""
    CV: _ContentType.ValueType  # 11
    """专栏，简单内容，biz_id是cvid"""
    VC: _ContentType.ValueType  # 12
    """废弃业务，无用"""
    WEB: _ContentType.ValueType  # 13
    """网址，简单内容，biz_id是网页链接"""
    TAOBAO: _ContentType.ValueType  # 14
    """淘宝内容，暂时不用"""
    MAIL: _ContentType.ValueType  # 15
    """邮箱，简单内容，biz_id是邮箱地址"""
    OGV_SEASON: _ContentType.ValueType  # 16
    """番剧season，简单内容，biz_id是番剧的season_id"""
    OGV_EP: _ContentType.ValueType  # 17
    """番剧ep，简单内容，biz_id是番剧的epid"""

class ContentType(_ContentType, metaclass=_ContentTypeEnumTypeWrapper):
    """"""

CONTENT_TYPE_NONE: ContentType.ValueType  # 0
"""占位"""
TEXT: ContentType.ValueType  # 1
"""文本，简单内容，biz_id就是文本"""
AT: ContentType.ValueType  # 2
"""@用户，简单内容，biz_id是用户uid"""
LOTTERY: ContentType.ValueType  # 3
"""抽奖，简单内容，biz_id是抽奖id"""
VOTE: ContentType.ValueType  # 4
"""投票，简单内容，biz_id是投票id"""
TOPIC: ContentType.ValueType  # 5
"""话题，简单内容，biz_id是话题id"""
GOODS: ContentType.ValueType  # 6
"""商品文字链，复杂内容，定义在GoodsContent结构，biz_id为空"""
BV: ContentType.ValueType  # 7
"""bv，简单内容，biz_id是bvid，包括"BV1"等内容"""
AV: ContentType.ValueType  # 8
"""av，简单内容，biz_id是avid"""
EMOJI: ContentType.ValueType  # 9
"""表情，简单内容，biz_id为空"""
USER: ContentType.ValueType  # 10
"""外露用户，暂未使用"""
CV: ContentType.ValueType  # 11
"""专栏，简单内容，biz_id是cvid"""
VC: ContentType.ValueType  # 12
"""废弃业务，无用"""
WEB: ContentType.ValueType  # 13
"""网址，简单内容，biz_id是网页链接"""
TAOBAO: ContentType.ValueType  # 14
"""淘宝内容，暂时不用"""
MAIL: ContentType.ValueType  # 15
"""邮箱，简单内容，biz_id是邮箱地址"""
OGV_SEASON: ContentType.ValueType  # 16
"""番剧season，简单内容，biz_id是番剧的season_id"""
OGV_EP: ContentType.ValueType  # 17
"""番剧ep，简单内容，biz_id是番剧的epid"""
global___ContentType = ContentType

class _CreateInitCheckScene:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CreateInitCheckSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CreateInitCheckScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CREATE_INIT_CHECK_SCENE_INVALID: _CreateInitCheckScene.ValueType  # 0
    """"""
    CREATE_INIT_CHECK_SCENE_NORMAL: _CreateInitCheckScene.ValueType  # 1
    """动态页面右上角点击进入发布页"""
    CREATE_INIT_CHECK_SCENE_REPOST: _CreateInitCheckScene.ValueType  # 2
    """动态feed流转发、三点分享，动态详情页转发"""
    CREATE_INIT_CHECK_SCENE_SHARE: _CreateInitCheckScene.ValueType  # 3
    """其他页面分享到动态"""
    CREATE_INIT_CHECK_SCENE_RESERVE_SHARE: _CreateInitCheckScene.ValueType  # 4
    """"""

class CreateInitCheckScene(_CreateInitCheckScene, metaclass=_CreateInitCheckSceneEnumTypeWrapper):
    """发布页预校验场景"""

CREATE_INIT_CHECK_SCENE_INVALID: CreateInitCheckScene.ValueType  # 0
""""""
CREATE_INIT_CHECK_SCENE_NORMAL: CreateInitCheckScene.ValueType  # 1
"""动态页面右上角点击进入发布页"""
CREATE_INIT_CHECK_SCENE_REPOST: CreateInitCheckScene.ValueType  # 2
"""动态feed流转发、三点分享，动态详情页转发"""
CREATE_INIT_CHECK_SCENE_SHARE: CreateInitCheckScene.ValueType  # 3
"""其他页面分享到动态"""
CREATE_INIT_CHECK_SCENE_RESERVE_SHARE: CreateInitCheckScene.ValueType  # 4
""""""
global___CreateInitCheckScene = CreateInitCheckScene

class _CreateScene:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CreateSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CreateScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CREATE_SCENE_INVALID: _CreateScene.ValueType  # 0
    """"""
    CREATE_SCENE_CREATE_WORD: _CreateScene.ValueType  # 1
    """发布纯文字动态"""
    CREATE_SCENE_CREATE_DRAW: _CreateScene.ValueType  # 2
    """发布图文动态"""
    CREATE_SCENE_CREATE_DYN_VIDEO: _CreateScene.ValueType  # 3
    """发布动态视频"""
    CREATE_SCENE_REPOST: _CreateScene.ValueType  # 4
    """转发动态"""
    CREATE_SCENE_SHARE_BIZ: _CreateScene.ValueType  # 5
    """分享业务方资源"""
    CREATE_SCENE_SHARE_PAGE: _CreateScene.ValueType  # 6
    """分享网页（通用模板）"""
    CREATE_SCENE_SHARE_PROGRAM: _CreateScene.ValueType  # 7
    """分享小程序"""
    CREATE_SCENE_REPLY_SYNC: _CreateScene.ValueType  # 8
    """评论同步到动态"""
    CREATE_SCENE_REPLY_CREATE_ACTIVITY: _CreateScene.ValueType  # 9
    """评论同步到动态并且发起活动"""

class CreateScene(_CreateScene, metaclass=_CreateSceneEnumTypeWrapper):
    """发布类型（场景）"""

CREATE_SCENE_INVALID: CreateScene.ValueType  # 0
""""""
CREATE_SCENE_CREATE_WORD: CreateScene.ValueType  # 1
"""发布纯文字动态"""
CREATE_SCENE_CREATE_DRAW: CreateScene.ValueType  # 2
"""发布图文动态"""
CREATE_SCENE_CREATE_DYN_VIDEO: CreateScene.ValueType  # 3
"""发布动态视频"""
CREATE_SCENE_REPOST: CreateScene.ValueType  # 4
"""转发动态"""
CREATE_SCENE_SHARE_BIZ: CreateScene.ValueType  # 5
"""分享业务方资源"""
CREATE_SCENE_SHARE_PAGE: CreateScene.ValueType  # 6
"""分享网页（通用模板）"""
CREATE_SCENE_SHARE_PROGRAM: CreateScene.ValueType  # 7
"""分享小程序"""
CREATE_SCENE_REPLY_SYNC: CreateScene.ValueType  # 8
"""评论同步到动态"""
CREATE_SCENE_REPLY_CREATE_ACTIVITY: CreateScene.ValueType  # 9
"""评论同步到动态并且发起活动"""
global___CreateScene = CreateScene

class _ReserveSource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReserveSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReserveSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESERVE_SOURCE_NEW: _ReserveSource.ValueType  # 0
    """"""
    RESERVE_SOURCE_ASSOCIATED: _ReserveSource.ValueType  # 1
    """"""

class ReserveSource(_ReserveSource, metaclass=_ReserveSourceEnumTypeWrapper):
    """"""

RESERVE_SOURCE_NEW: ReserveSource.ValueType  # 0
""""""
RESERVE_SOURCE_ASSOCIATED: ReserveSource.ValueType  # 1
""""""
global___ReserveSource = ReserveSource

class _UpPermissionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UpPermissionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UpPermissionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UP_PERMISSION_TYPE_NONE: _UpPermissionType.ValueType  # 0
    """占位"""
    UP_PERMISSION_TYPE_LOTTERY: _UpPermissionType.ValueType  # 1
    """是否是抽奖的灰度用户，默认不是"""
    UP_PERMISSION_TYPE_CLIP_PUBLISHED: _UpPermissionType.ValueType  # 2
    """之前是否发过小视频，默认没发过"""
    UP_PERMISSION_TYPE_UGC_ATTACH_CARD: _UpPermissionType.ValueType  # 3
    """是否可以添加ugc附加卡，默认不可以"""
    UP_PERMISSION_TYPE_GOODS_ATTACH_CARD: _UpPermissionType.ValueType  # 4
    """是否有权限添加商品附加卡"""
    UP_PERMISSION_TYPE_CHOOSE_COMMENT: _UpPermissionType.ValueType  # 5
    """是否有权限自主精选评论白名单，默认没有"""
    UP_PERMISSION_TYPE_CONTROL_COMMENT: _UpPermissionType.ValueType  # 6
    """是否有权限关闭评论区，默认有"""
    UP_PERMISSION_TYPE_CONTROL_DANMU: _UpPermissionType.ValueType  # 7
    """是否有权限关闭弹幕（仅对动态视频生效），默认有"""
    UP_PERMISSION_TYPE_VIDEO_RESERVE: _UpPermissionType.ValueType  # 8
    """是否可以发起稿件预约"""
    UP_PERMISSION_TYPE_LIVE_RESERVE: _UpPermissionType.ValueType  # 9
    """是否可以发起直播预约"""

class UpPermissionType(_UpPermissionType, metaclass=_UpPermissionTypeEnumTypeWrapper):
    """"""

UP_PERMISSION_TYPE_NONE: UpPermissionType.ValueType  # 0
"""占位"""
UP_PERMISSION_TYPE_LOTTERY: UpPermissionType.ValueType  # 1
"""是否是抽奖的灰度用户，默认不是"""
UP_PERMISSION_TYPE_CLIP_PUBLISHED: UpPermissionType.ValueType  # 2
"""之前是否发过小视频，默认没发过"""
UP_PERMISSION_TYPE_UGC_ATTACH_CARD: UpPermissionType.ValueType  # 3
"""是否可以添加ugc附加卡，默认不可以"""
UP_PERMISSION_TYPE_GOODS_ATTACH_CARD: UpPermissionType.ValueType  # 4
"""是否有权限添加商品附加卡"""
UP_PERMISSION_TYPE_CHOOSE_COMMENT: UpPermissionType.ValueType  # 5
"""是否有权限自主精选评论白名单，默认没有"""
UP_PERMISSION_TYPE_CONTROL_COMMENT: UpPermissionType.ValueType  # 6
"""是否有权限关闭评论区，默认有"""
UP_PERMISSION_TYPE_CONTROL_DANMU: UpPermissionType.ValueType  # 7
"""是否有权限关闭弹幕（仅对动态视频生效），默认有"""
UP_PERMISSION_TYPE_VIDEO_RESERVE: UpPermissionType.ValueType  # 8
"""是否可以发起稿件预约"""
UP_PERMISSION_TYPE_LIVE_RESERVE: UpPermissionType.ValueType  # 9
"""是否可以发起直播预约"""
global___UpPermissionType = UpPermissionType

@typing_extensions.final
class AtGroup(google.protobuf.message.Message):
    """at分组信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_TYPE_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    group_type: global___AtGroupType.ValueType
    """分组类型"""
    group_name: builtins.str
    """分组名称"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtItem]:
        """items"""
    def __init__(
        self,
        *,
        group_type: global___AtGroupType.ValueType = ...,
        group_name: builtins.str = ...,
        items: collections.abc.Iterable[global___AtItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_name", b"group_name", "group_type", b"group_type", "items", b"items"]) -> None: ...

global___AtGroup = AtGroup

@typing_extensions.final
class AtItem(google.protobuf.message.Message):
    """at返回单条信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_TYPE_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """mid"""
    name: builtins.str
    """昵称"""
    face: builtins.str
    """头像"""
    fans: builtins.int
    """粉丝数"""
    official_verify_type: builtins.int
    """认证信息"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        fans: builtins.int = ...,
        official_verify_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "fans", b"fans", "name", b"name", "official_verify_type", b"official_verify_type", "uid", b"uid"]) -> None: ...

global___AtItem = AtItem

@typing_extensions.final
class AtListReq(google.protobuf.message.Message):
    """at列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """mid"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uid", b"uid"]) -> None: ...

global___AtListReq = AtListReq

@typing_extensions.final
class AtListRsp(google.protobuf.message.Message):
    """at列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPS_FIELD_NUMBER: builtins.int
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtGroup]:
        """分组信息"""
    def __init__(
        self,
        *,
        groups: collections.abc.Iterable[global___AtGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["groups", b"groups"]) -> None: ...

global___AtListRsp = AtListRsp

@typing_extensions.final
class AtSearchReq(google.protobuf.message.Message):
    """at搜索-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """mid"""
    keyword: builtins.str
    """关键字"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        keyword: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyword", b"keyword", "uid", b"uid"]) -> None: ...

global___AtSearchReq = AtSearchReq

@typing_extensions.final
class BottomBusiness(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    rid: builtins.int
    """业务方资源id"""
    type: builtins.int
    """业务方类型，定义在BottomBizType中"""
    def __init__(
        self,
        *,
        rid: builtins.int = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rid", b"rid", "type", b"type"]) -> None: ...

global___BottomBusiness = BottomBusiness

@typing_extensions.final
class CreateActivity(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_STATE_FIELD_NUMBER: builtins.int
    IS_NEW_ACTIVITY_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """"""
    activity_state: builtins.int
    """"""
    is_new_activity: builtins.int
    """"""
    action: builtins.int
    """"""
    def __init__(
        self,
        *,
        activity_id: builtins.int = ...,
        activity_state: builtins.int = ...,
        is_new_activity: builtins.int = ...,
        action: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "activity_id", b"activity_id", "activity_state", b"activity_state", "is_new_activity", b"is_new_activity"]) -> None: ...

global___CreateActivity = CreateActivity

@typing_extensions.final
class CreateAttachCard(google.protobuf.message.Message):
    """动态附带的附加大卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GOODS_FIELD_NUMBER: builtins.int
    COMMON_CARD_FIELD_NUMBER: builtins.int
    @property
    def goods(self) -> global___CreateGoodsCard:
        """商品大卡"""
    @property
    def common_card(self) -> global___CreateCommonAttachCard:
        """通用附加大卡，目前仅限定Match,Game,Ugc,Pugv,Reserve，且同时只能有一个"""
    def __init__(
        self,
        *,
        goods: global___CreateGoodsCard | None = ...,
        common_card: global___CreateCommonAttachCard | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["common_card", b"common_card", "goods", b"goods"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_card", b"common_card", "goods", b"goods"]) -> None: ...

global___CreateAttachCard = CreateAttachCard

@typing_extensions.final
class CreateCheckResp(google.protobuf.message.Message):
    """发布页预校验-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SETTING_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    SHARE_INFO_FIELD_NUMBER: builtins.int
    YELLOW_BAR_FIELD_NUMBER: builtins.int
    PLUS_RED_DOT_FIELD_NUMBER: builtins.int
    @property
    def setting(self) -> global___PublishSetting:
        """发布相关的配置项"""
    @property
    def permission(self) -> global___UpPermission:
        """用户具有的发布权限"""
    @property
    def share_info(self) -> global___ShareChannel:
        """分享渠道信息"""
    @property
    def yellow_bar(self) -> global___PublishYellowBar:
        """小黄条"""
    @property
    def plus_red_dot(self) -> global___PlusRedDot:
        """"""
    def __init__(
        self,
        *,
        setting: global___PublishSetting | None = ...,
        permission: global___UpPermission | None = ...,
        share_info: global___ShareChannel | None = ...,
        yellow_bar: global___PublishYellowBar | None = ...,
        plus_red_dot: global___PlusRedDot | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["permission", b"permission", "plus_red_dot", b"plus_red_dot", "setting", b"setting", "share_info", b"share_info", "yellow_bar", b"yellow_bar"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["permission", b"permission", "plus_red_dot", b"plus_red_dot", "setting", b"setting", "share_info", b"share_info", "yellow_bar", b"yellow_bar"]) -> None: ...

global___CreateCheckResp = CreateCheckResp

@typing_extensions.final
class CreateCommonAttachCard(google.protobuf.message.Message):
    """创建动态时附带的通用附加卡详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    RESERVE_SOURCE_FIELD_NUMBER: builtins.int
    RESERVE_LOTTERY_FIELD_NUMBER: builtins.int
    type: global___AttachCardType.ValueType
    """通用附加卡的类型"""
    biz_id: builtins.int
    """通用附加卡的业务id"""
    reserve_source: builtins.int
    """"""
    reserve_lottery: builtins.int
    """"""
    def __init__(
        self,
        *,
        type: global___AttachCardType.ValueType = ...,
        biz_id: builtins.int = ...,
        reserve_source: builtins.int = ...,
        reserve_lottery: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "reserve_lottery", b"reserve_lottery", "reserve_source", b"reserve_source", "type", b"type"]) -> None: ...

global___CreateCommonAttachCard = CreateCommonAttachCard

@typing_extensions.final
class CreateContent(google.protobuf.message.Message):
    """动态-描述文字模块"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENTS_FIELD_NUMBER: builtins.int
    @property
    def contents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreateContentItem]:
        """描述信息（已按高亮拆分）"""
    def __init__(
        self,
        *,
        contents: collections.abc.Iterable[global___CreateContentItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["contents", b"contents"]) -> None: ...

global___CreateContent = CreateContent

@typing_extensions.final
class CreateContentItem(google.protobuf.message.Message):
    """文本描述"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    GOODS_FIELD_NUMBER: builtins.int
    raw_text: builtins.str
    """原始文案"""
    type: global___ContentType.ValueType
    """类型"""
    biz_id: builtins.str
    """简单内容，可能为文字，BVID，AVID，uid等；复杂内容需要单独定义结构体"""
    @property
    def goods(self) -> global___GoodsContent:
        """商品内容"""
    def __init__(
        self,
        *,
        raw_text: builtins.str = ...,
        type: global___ContentType.ValueType = ...,
        biz_id: builtins.str = ...,
        goods: global___GoodsContent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["goods", b"goods"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "goods", b"goods", "raw_text", b"raw_text", "type", b"type"]) -> None: ...

global___CreateContentItem = CreateContentItem

@typing_extensions.final
class CreateDynVideo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATION_FROM_FIELD_NUMBER: builtins.int
    BIZ_FROM_FIELD_NUMBER: builtins.int
    COPYRIGHT_FIELD_NUMBER: builtins.int
    NO_PUBLIC_FIELD_NUMBER: builtins.int
    NO_REPRINT_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    DESC_FORMAT_ID_FIELD_NUMBER: builtins.int
    OPEN_ELEC_FIELD_NUMBER: builtins.int
    DTIME_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    WATERMARK_FIELD_NUMBER: builtins.int
    MISSION_ID_FIELD_NUMBER: builtins.int
    DYNAMIC_FIELD_NUMBER: builtins.int
    DYNAMIC_EXTENSION_FIELD_NUMBER: builtins.int
    DYNAMIC_CTRL_FIELD_NUMBER: builtins.int
    DYNAMIC_FROM_FIELD_NUMBER: builtins.int
    LOTTERY_ID_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    UP_SELECTION_REPLY_FIELD_NUMBER: builtins.int
    UP_CLOSE_REPLY_FIELD_NUMBER: builtins.int
    UP_CLOSE_DANMU_FIELD_NUMBER: builtins.int
    UP_FROM_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    relation_from: builtins.str
    """投稿平台来源，具体写什么@产品"""
    biz_from: builtins.int
    """1 — 投稿入口 + 相册选择视频 2 — 投稿入口 + 拍摄 3 — 小视频入口 + 相册选择视频 4 — 小视频入口 + 拍摄"""
    copyright: builtins.int
    """投稿类型:  2-转载、1-自制"""
    no_public: builtins.int
    """是否公开投稿 0允许公开，1不允许公开 默认 0公开"""
    no_reprint: builtins.int
    """是否允许转载字段 0允许，1不允许，默认为0    copyright = 1 自制的时候默认勾选上no_reprint=1"""
    source: builtins.str
    """转载的时候必须填写，非空字符串"""
    cover: builtins.str
    """稿件封面必须填写,不能为空 封面不支持其他源站链接 请确保 cover 是 先经过上传接口"""
    title: builtins.str
    """稿件标题"""
    tid: builtins.int
    """稿件分区ID 必须是有效的二级分区ID"""
    tag: builtins.str
    """标签 多个标签请使用英文逗号连接"""
    desc: builtins.str
    """稿件描述"""
    desc_format_id: builtins.int
    """当前输入环境下有，就输入http://domain/x/app/archive/desc/format返回的desc_format值
    如果返回null就输入默认为0， 表示当前环境（分区+投稿类型）不参与简介格式化
    """
    open_elec: builtins.int
    """稿件是否开启充电面板，1为是, 0为否"""
    dtime: builtins.int
    """定时发布的时间"""
    @property
    def videos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynVideoMultiP]:
        """分P聚合字段"""
    @property
    def watermark(self) -> global___DynVideoWatermark:
        """水印信息"""
    mission_id: builtins.int
    """新增加通过tag来参加活动"""
    dynamic: builtins.str
    """新增加可以添加动态内容"""
    dynamic_extension: builtins.str
    """序列化后的extend_info扩展信息"""
    dynamic_ctrl: builtins.str
    """客户端控制字段"""
    dynamic_from: builtins.str
    """动态来源"""
    lottery_id: builtins.int
    """抽奖服务生成的ID"""
    @property
    def vote(self) -> global___DynVideoVote:
        """"""
    up_selection_reply: builtins.bool
    """精选评论开关, true为开"""
    up_close_reply: builtins.bool
    """up主关闭评论"""
    up_close_danmu: builtins.bool
    """up主关闭弹幕"""
    up_from: builtins.int
    """稿件投稿来源"""
    duration: builtins.int
    """"""
    def __init__(
        self,
        *,
        relation_from: builtins.str = ...,
        biz_from: builtins.int = ...,
        copyright: builtins.int = ...,
        no_public: builtins.int = ...,
        no_reprint: builtins.int = ...,
        source: builtins.str = ...,
        cover: builtins.str = ...,
        title: builtins.str = ...,
        tid: builtins.int = ...,
        tag: builtins.str = ...,
        desc: builtins.str = ...,
        desc_format_id: builtins.int = ...,
        open_elec: builtins.int = ...,
        dtime: builtins.int = ...,
        videos: collections.abc.Iterable[global___DynVideoMultiP] | None = ...,
        watermark: global___DynVideoWatermark | None = ...,
        mission_id: builtins.int = ...,
        dynamic: builtins.str = ...,
        dynamic_extension: builtins.str = ...,
        dynamic_ctrl: builtins.str = ...,
        dynamic_from: builtins.str = ...,
        lottery_id: builtins.int = ...,
        vote: global___DynVideoVote | None = ...,
        up_selection_reply: builtins.bool = ...,
        up_close_reply: builtins.bool = ...,
        up_close_danmu: builtins.bool = ...,
        up_from: builtins.int = ...,
        duration: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vote", b"vote", "watermark", b"watermark"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_from", b"biz_from", "copyright", b"copyright", "cover", b"cover", "desc", b"desc", "desc_format_id", b"desc_format_id", "dtime", b"dtime", "duration", b"duration", "dynamic", b"dynamic", "dynamic_ctrl", b"dynamic_ctrl", "dynamic_extension", b"dynamic_extension", "dynamic_from", b"dynamic_from", "lottery_id", b"lottery_id", "mission_id", b"mission_id", "no_public", b"no_public", "no_reprint", b"no_reprint", "open_elec", b"open_elec", "relation_from", b"relation_from", "source", b"source", "tag", b"tag", "tid", b"tid", "title", b"title", "up_close_danmu", b"up_close_danmu", "up_close_reply", b"up_close_reply", "up_from", b"up_from", "up_selection_reply", b"up_selection_reply", "videos", b"videos", "vote", b"vote", "watermark", b"watermark"]) -> None: ...

global___CreateDynVideo = CreateDynVideo

@typing_extensions.final
class CreateDynVideoResult(google.protobuf.message.Message):
    """创建动态视频的应答包（透传给客户端）"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    SUBMITACT_BANNER_FIELD_NUMBER: builtins.int
    PUSH_INTRO_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件id"""
    message: builtins.str
    """说明信息"""
    @property
    def submitact_banner(self) -> global___DynVideoSubmitActBanner:
        """推荐的活动信息"""
    @property
    def push_intro(self) -> global___DynVideoPushIntro:
        """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        message: builtins.str = ...,
        submitact_banner: global___DynVideoSubmitActBanner | None = ...,
        push_intro: global___DynVideoPushIntro | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["push_intro", b"push_intro", "submitact_banner", b"submitact_banner"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "message", b"message", "push_intro", b"push_intro", "submitact_banner", b"submitact_banner"]) -> None: ...

global___CreateDynVideoResult = CreateDynVideoResult

@typing_extensions.final
class CreateGoodsCard(google.protobuf.message.Message):
    """创建动态时附带的商品大卡详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_ID_FIELD_NUMBER: builtins.int
    @property
    def item_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """商品大卡中的商品id"""
    def __init__(
        self,
        *,
        item_id: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_id", b"item_id"]) -> None: ...

global___CreateGoodsCard = CreateGoodsCard

@typing_extensions.final
class CreateOption(google.protobuf.message.Message):
    """动态创建时的特殊选项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UP_CHOOSE_COMMENT_FIELD_NUMBER: builtins.int
    CLOSE_COMMENT_FIELD_NUMBER: builtins.int
    FOLD_EXCLUDE_FIELD_NUMBER: builtins.int
    AUDIT_LEVEL_FIELD_NUMBER: builtins.int
    SYNC_TO_COMMENT_FIELD_NUMBER: builtins.int
    VIDEO_SHARE_INFO_FIELD_NUMBER: builtins.int
    ACTIVITY_FIELD_NUMBER: builtins.int
    up_choose_comment: builtins.int
    """评论区展示UP自己精选的评论"""
    close_comment: builtins.int
    """初始评论区是关闭状态"""
    fold_exclude: builtins.int
    """该动态不会被折叠
    目前仅抽奖开奖动态不会被折叠
    """
    audit_level: builtins.int
    """审核等级，仅服务端发布时有效
    100：自动过审
    非100：默认的内网审核
    默认为0
    """
    sync_to_comment: builtins.int
    """根据转发内容同步生成一条源动态/资源的评论
    仅转发和分享时有效
    """
    @property
    def video_share_info(self) -> global___VideoShareInfo:
        """"""
    @property
    def activity(self) -> global___CreateActivity:
        """"""
    def __init__(
        self,
        *,
        up_choose_comment: builtins.int = ...,
        close_comment: builtins.int = ...,
        fold_exclude: builtins.int = ...,
        audit_level: builtins.int = ...,
        sync_to_comment: builtins.int = ...,
        video_share_info: global___VideoShareInfo | None = ...,
        activity: global___CreateActivity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity", b"activity", "video_share_info", b"video_share_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity", b"activity", "audit_level", b"audit_level", "close_comment", b"close_comment", "fold_exclude", b"fold_exclude", "sync_to_comment", b"sync_to_comment", "up_choose_comment", b"up_choose_comment", "video_share_info", b"video_share_info"]) -> None: ...

global___CreateOption = CreateOption

@typing_extensions.final
class CreatePic(google.protobuf.message.Message):
    """创建图文动态时的图片信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMG_SRC_FIELD_NUMBER: builtins.int
    IMG_WIDTH_FIELD_NUMBER: builtins.int
    IMG_HEIGHT_FIELD_NUMBER: builtins.int
    IMG_SIZE_FIELD_NUMBER: builtins.int
    IMG_TAGS_FIELD_NUMBER: builtins.int
    img_src: builtins.str
    """上传图片URL"""
    img_width: builtins.float
    """图片宽度"""
    img_height: builtins.float
    """图片高度"""
    img_size: builtins.float
    """图片大小，单位KB"""
    @property
    def img_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreatePicTag]:
        """"""
    def __init__(
        self,
        *,
        img_src: builtins.str = ...,
        img_width: builtins.float = ...,
        img_height: builtins.float = ...,
        img_size: builtins.float = ...,
        img_tags: collections.abc.Iterable[global___CreatePicTag] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["img_height", b"img_height", "img_size", b"img_size", "img_src", b"img_src", "img_tags", b"img_tags", "img_width", b"img_width"]) -> None: ...

global___CreatePic = CreatePic

@typing_extensions.final
class CreatePicTag(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_ID_FIELD_NUMBER: builtins.int
    TID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_STRING_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    SCHEMA_URL_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    ORIENTATION_FIELD_NUMBER: builtins.int
    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    POI_FIELD_NUMBER: builtins.int
    item_id: builtins.int
    """"""
    tid: builtins.int
    """"""
    mid: builtins.int
    """"""
    text: builtins.str
    """"""
    text_string: builtins.str
    """"""
    type: builtins.int
    """"""
    source_type: builtins.int
    """"""
    url: builtins.str
    """"""
    schema_url: builtins.str
    """"""
    jump_url: builtins.str
    """"""
    orientation: builtins.int
    """"""
    x: builtins.int
    """"""
    y: builtins.int
    """"""
    poi: builtins.str
    """"""
    def __init__(
        self,
        *,
        item_id: builtins.int = ...,
        tid: builtins.int = ...,
        mid: builtins.int = ...,
        text: builtins.str = ...,
        text_string: builtins.str = ...,
        type: builtins.int = ...,
        source_type: builtins.int = ...,
        url: builtins.str = ...,
        schema_url: builtins.str = ...,
        jump_url: builtins.str = ...,
        orientation: builtins.int = ...,
        x: builtins.int = ...,
        y: builtins.int = ...,
        poi: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_id", b"item_id", "jump_url", b"jump_url", "mid", b"mid", "orientation", b"orientation", "poi", b"poi", "schema_url", b"schema_url", "source_type", b"source_type", "text", b"text", "text_string", b"text_string", "tid", b"tid", "type", b"type", "url", b"url", "x", b"x", "y", b"y"]) -> None: ...

global___CreatePicTag = CreatePicTag

@typing_extensions.final
class CreateResp(google.protobuf.message.Message):
    """创建动态-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYN_ID_FIELD_NUMBER: builtins.int
    DYN_ID_STR_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    DYN_RID_FIELD_NUMBER: builtins.int
    FAKE_CARD_FIELD_NUMBER: builtins.int
    VIDEO_RESULT_FIELD_NUMBER: builtins.int
    dyn_id: builtins.int
    """动态id"""
    dyn_id_str: builtins.str
    """动态id str"""
    dyn_type: builtins.int
    """动态的类型"""
    dyn_rid: builtins.int
    """动态id"""
    @property
    def fake_card(self) -> bilireq.grpc.protos.bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem:
        """假卡"""
    @property
    def video_result(self) -> global___CreateDynVideoResult:
        """视频"""
    def __init__(
        self,
        *,
        dyn_id: builtins.int = ...,
        dyn_id_str: builtins.str = ...,
        dyn_type: builtins.int = ...,
        dyn_rid: builtins.int = ...,
        fake_card: bilibili.app.dynamic.v2.dynamic_pb2.DynamicItem | None = ...,
        video_result: global___CreateDynVideoResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fake_card", b"fake_card", "video_result", b"video_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_id", b"dyn_id", "dyn_id_str", b"dyn_id_str", "dyn_rid", b"dyn_rid", "dyn_type", b"dyn_type", "fake_card", b"fake_card", "video_result", b"video_result"]) -> None: ...

global___CreateResp = CreateResp

@typing_extensions.final
class CreateTag(google.protobuf.message.Message):
    """动态附带的小卡"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LBS_FIELD_NUMBER: builtins.int
    SDK_GAME_FIELD_NUMBER: builtins.int
    DIVERSION_FIELD_NUMBER: builtins.int
    @property
    def lbs(self) -> global___ExtLbs:
        """lbs小卡"""
    @property
    def sdk_game(self) -> global___BottomBusiness:
        """游戏通过SDK发布的动态需要带上游戏小卡"""
    @property
    def diversion(self) -> global___BottomBusiness:
        """必剪发布的动态需要带上必剪小卡"""
    def __init__(
        self,
        *,
        lbs: global___ExtLbs | None = ...,
        sdk_game: global___BottomBusiness | None = ...,
        diversion: global___BottomBusiness | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["diversion", b"diversion", "lbs", b"lbs", "sdk_game", b"sdk_game"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["diversion", b"diversion", "lbs", b"lbs", "sdk_game", b"sdk_game"]) -> None: ...

global___CreateTag = CreateTag

@typing_extensions.final
class CreateTopic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name"]) -> None: ...

global___CreateTopic = CreateTopic

@typing_extensions.final
class DynIdentity(google.protobuf.message.Message):
    """动态的标识"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYN_ID_FIELD_NUMBER: builtins.int
    REVS_ID_FIELD_NUMBER: builtins.int
    dyn_id: builtins.int
    """动态id"""
    @property
    def revs_id(self) -> global___DynRevsId:
        """动态反向id，通过(type+rid组合)也可以唯一标识一个动态，与dyn_id出现任意一个即可"""
    def __init__(
        self,
        *,
        dyn_id: builtins.int = ...,
        revs_id: global___DynRevsId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["revs_id", b"revs_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_id", b"dyn_id", "revs_id", b"revs_id"]) -> None: ...

global___DynIdentity = DynIdentity

@typing_extensions.final
class DynRevsId(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DYN_TYPE_FIELD_NUMBER: builtins.int
    RID_FIELD_NUMBER: builtins.int
    dyn_type: builtins.int
    """动态类型"""
    rid: builtins.int
    """业务id"""
    def __init__(
        self,
        *,
        dyn_type: builtins.int = ...,
        rid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dyn_type", b"dyn_type", "rid", b"rid"]) -> None: ...

global___DynRevsId = DynRevsId

@typing_extensions.final
class DynVideoEditor(google.protobuf.message.Message):
    """动态视频分P视频编辑环境上报信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    UPFROM_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    FONTS_FIELD_NUMBER: builtins.int
    SUBTITLES_FIELD_NUMBER: builtins.int
    BGMS_FIELD_NUMBER: builtins.int
    STICKERS_FIELD_NUMBER: builtins.int
    VIDEOUP_STICKERS_FIELD_NUMBER: builtins.int
    TRANS_FIELD_NUMBER: builtins.int
    MAKEUPS_FIELD_NUMBER: builtins.int
    SURGERYS_FIELD_NUMBER: builtins.int
    VIDEOFXS_FIELD_NUMBER: builtins.int
    THEMES_FIELD_NUMBER: builtins.int
    COOPERATES_FIELD_NUMBER: builtins.int
    RHYTHMS_FIELD_NUMBER: builtins.int
    EFFECTS_FIELD_NUMBER: builtins.int
    BACKGROUNDS_FIELD_NUMBER: builtins.int
    VIDEOS_FIELD_NUMBER: builtins.int
    SOUNDS_FIELD_NUMBER: builtins.int
    FLOWERS_FIELD_NUMBER: builtins.int
    COVER_TEMPLATES_FIELD_NUMBER: builtins.int
    TTS_FIELD_NUMBER: builtins.int
    OPENINGS_FIELD_NUMBER: builtins.int
    RECORD_TEXT_FIELD_NUMBER: builtins.int
    VUPERS_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    BCUT_FEATURES_FIELD_NUMBER: builtins.int
    AUDIO_RECORD_FIELD_NUMBER: builtins.int
    CAMERA_FIELD_NUMBER: builtins.int
    SPEED_FIELD_NUMBER: builtins.int
    CAMERA_ROTATE_FIELD_NUMBER: builtins.int
    SCREEN_RECORD_FIELD_NUMBER: builtins.int
    DEFAULT_END_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    PIC_COUNT_FIELD_NUMBER: builtins.int
    VIDEO_COUNT_FIELD_NUMBER: builtins.int
    SHOT_DURATION_FIELD_NUMBER: builtins.int
    SHOT_GAME_FIELD_NUMBER: builtins.int
    HIGHLIGHT_FIELD_NUMBER: builtins.int
    HIGHLIGHT_CNT_FIELD_NUMBER: builtins.int
    PIP_COUNT_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """"""
    upfrom: builtins.int
    """"""
    filters: builtins.str
    """滤镜"""
    fonts: builtins.str
    """字体"""
    subtitles: builtins.str
    """字幕"""
    bgms: builtins.str
    """bgm"""
    stickers: builtins.str
    """3d拍摄贴纸"""
    videoup_stickers: builtins.str
    """2d投稿贴纸"""
    trans: builtins.str
    """视频转场特效"""
    makeups: builtins.str
    """编辑器的主题使用相关"""
    surgerys: builtins.str
    """整容之外科手术"""
    videofxs: builtins.str
    """美摄特定的videofx"""
    themes: builtins.str
    """编辑器的主题使用相关"""
    cooperates: builtins.str
    """拍摄之稿件合拍"""
    rhythms: builtins.str
    """拍摄之音乐卡点视频"""
    effects: builtins.str
    """mvp特效"""
    backgrounds: builtins.str
    """mvp背景"""
    videos: builtins.str
    """mvp视频"""
    sounds: builtins.str
    """mvp音效"""
    flowers: builtins.str
    """mvp花字"""
    cover_templates: builtins.str
    """mvp封面模板"""
    tts: builtins.str
    """tts"""
    openings: builtins.str
    """openings"""
    record_text: builtins.bool
    """录音题词"""
    vupers: builtins.str
    """虚拟形象上报"""
    features: builtins.str
    """"""
    bcut_features: builtins.str
    """"""
    audio_record: builtins.int
    """"""
    camera: builtins.int
    """"""
    speed: builtins.int
    """"""
    camera_rotate: builtins.int
    """"""
    screen_record: builtins.int
    """"""
    default_end: builtins.int
    """"""
    duration: builtins.int
    """"""
    pic_count: builtins.int
    """"""
    video_count: builtins.int
    """"""
    shot_duration: builtins.int
    """"""
    shot_game: builtins.str
    """"""
    highlight: builtins.bool
    """"""
    highlight_cnt: builtins.int
    """"""
    pip_count: builtins.int
    """"""
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
        upfrom: builtins.int = ...,
        filters: builtins.str = ...,
        fonts: builtins.str = ...,
        subtitles: builtins.str = ...,
        bgms: builtins.str = ...,
        stickers: builtins.str = ...,
        videoup_stickers: builtins.str = ...,
        trans: builtins.str = ...,
        makeups: builtins.str = ...,
        surgerys: builtins.str = ...,
        videofxs: builtins.str = ...,
        themes: builtins.str = ...,
        cooperates: builtins.str = ...,
        rhythms: builtins.str = ...,
        effects: builtins.str = ...,
        backgrounds: builtins.str = ...,
        videos: builtins.str = ...,
        sounds: builtins.str = ...,
        flowers: builtins.str = ...,
        cover_templates: builtins.str = ...,
        tts: builtins.str = ...,
        openings: builtins.str = ...,
        record_text: builtins.bool = ...,
        vupers: builtins.str = ...,
        features: builtins.str = ...,
        bcut_features: builtins.str = ...,
        audio_record: builtins.int = ...,
        camera: builtins.int = ...,
        speed: builtins.int = ...,
        camera_rotate: builtins.int = ...,
        screen_record: builtins.int = ...,
        default_end: builtins.int = ...,
        duration: builtins.int = ...,
        pic_count: builtins.int = ...,
        video_count: builtins.int = ...,
        shot_duration: builtins.int = ...,
        shot_game: builtins.str = ...,
        highlight: builtins.bool = ...,
        highlight_cnt: builtins.int = ...,
        pip_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_record", b"audio_record", "backgrounds", b"backgrounds", "bcut_features", b"bcut_features", "bgms", b"bgms", "camera", b"camera", "camera_rotate", b"camera_rotate", "cid", b"cid", "cooperates", b"cooperates", "cover_templates", b"cover_templates", "default_end", b"default_end", "duration", b"duration", "effects", b"effects", "features", b"features", "filters", b"filters", "flowers", b"flowers", "fonts", b"fonts", "highlight", b"highlight", "highlight_cnt", b"highlight_cnt", "makeups", b"makeups", "openings", b"openings", "pic_count", b"pic_count", "pip_count", b"pip_count", "record_text", b"record_text", "rhythms", b"rhythms", "screen_record", b"screen_record", "shot_duration", b"shot_duration", "shot_game", b"shot_game", "sounds", b"sounds", "speed", b"speed", "stickers", b"stickers", "subtitles", b"subtitles", "surgerys", b"surgerys", "themes", b"themes", "trans", b"trans", "tts", b"tts", "upfrom", b"upfrom", "video_count", b"video_count", "videofxs", b"videofxs", "videos", b"videos", "videoup_stickers", b"videoup_stickers", "vupers", b"vupers"]) -> None: ...

global___DynVideoEditor = DynVideoEditor

@typing_extensions.final
class DynVideoHotAct(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACT_ID_FIELD_NUMBER: builtins.int
    ETIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    act_id: builtins.int
    """"""
    etime: builtins.int
    """"""
    id: builtins.int
    """"""
    pic: builtins.str
    """"""
    stime: builtins.int
    """"""
    title: builtins.str
    """"""
    link: builtins.str
    """"""
    def __init__(
        self,
        *,
        act_id: builtins.int = ...,
        etime: builtins.int = ...,
        id: builtins.int = ...,
        pic: builtins.str = ...,
        stime: builtins.int = ...,
        title: builtins.str = ...,
        link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["act_id", b"act_id", "etime", b"etime", "id", b"id", "link", b"link", "pic", b"pic", "stime", b"stime", "title", b"title"]) -> None: ...

global___DynVideoHotAct = DynVideoHotAct

@typing_extensions.final
class DynVideoMultiP(google.protobuf.message.Message):
    """动态视频分P聚合字段"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    title: builtins.str
    """分P标题"""
    filename: builtins.str
    """分P的文件名"""
    cid: builtins.int
    """"""
    @property
    def editor(self) -> global___DynVideoEditor:
        """编辑环境上报信息"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        filename: builtins.str = ...,
        cid: builtins.int = ...,
        editor: global___DynVideoEditor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["editor", b"editor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "editor", b"editor", "filename", b"filename", "title", b"title"]) -> None: ...

global___DynVideoMultiP = DynVideoMultiP

@typing_extensions.final
class DynVideoPushIntro(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    show: builtins.int
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        show: builtins.int = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["show", b"show", "text", b"text"]) -> None: ...

global___DynVideoPushIntro = DynVideoPushIntro

@typing_extensions.final
class DynVideoSubmitActBanner(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOTACT_TEXT_FIELD_NUMBER: builtins.int
    HOTACT_URL_FIELD_NUMBER: builtins.int
    LIST_FIELD_NUMBER: builtins.int
    hotact_text: builtins.str
    """"""
    hotact_url: builtins.str
    """"""
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DynVideoHotAct]:
        """"""
    def __init__(
        self,
        *,
        hotact_text: builtins.str = ...,
        hotact_url: builtins.str = ...,
        list: collections.abc.Iterable[global___DynVideoHotAct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hotact_text", b"hotact_text", "hotact_url", b"hotact_url", "list", b"list"]) -> None: ...

global___DynVideoSubmitActBanner = DynVideoSubmitActBanner

@typing_extensions.final
class DynVideoVote(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOTE_ID_FIELD_NUMBER: builtins.int
    VOTE_TITLE_FIELD_NUMBER: builtins.int
    TOP_FOR_REPLY_FIELD_NUMBER: builtins.int
    vote_id: builtins.int
    """"""
    vote_title: builtins.str
    """"""
    top_for_reply: builtins.int
    """"""
    def __init__(
        self,
        *,
        vote_id: builtins.int = ...,
        vote_title: builtins.str = ...,
        top_for_reply: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["top_for_reply", b"top_for_reply", "vote_id", b"vote_id", "vote_title", b"vote_title"]) -> None: ...

global___DynVideoVote = DynVideoVote

@typing_extensions.final
class DynVideoWatermark(google.protobuf.message.Message):
    """动态视频水印信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    state: builtins.int
    """水印状态 
    0-关闭 1-打开 2-预览
    """
    type: builtins.int
    """类型
    1-用户昵称类型 2-用户id类型 3-用户名在logo下面
    """
    position: builtins.int
    """位置
    1-左上 2-右上 3-左下 4-右下
    """
    def __init__(
        self,
        *,
        state: builtins.int = ...,
        type: builtins.int = ...,
        position: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["position", b"position", "state", b"state", "type", b"type"]) -> None: ...

global___DynVideoWatermark = DynVideoWatermark

@typing_extensions.final
class ExtLbs(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    DISTANCE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    POI_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    SHOW_TITLE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SHOW_DISTANCE_FIELD_NUMBER: builtins.int
    address: builtins.str
    """"""
    distance: builtins.int
    """"""
    type: builtins.int
    """"""
    poi: builtins.str
    """"""
    @property
    def location(self) -> global___LbsLoc:
        """"""
    show_title: builtins.str
    """"""
    title: builtins.str
    """"""
    show_distance: builtins.str
    """"""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        distance: builtins.int = ...,
        type: builtins.int = ...,
        poi: builtins.str = ...,
        location: global___LbsLoc | None = ...,
        show_title: builtins.str = ...,
        title: builtins.str = ...,
        show_distance: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "distance", b"distance", "location", b"location", "poi", b"poi", "show_distance", b"show_distance", "show_title", b"show_title", "title", b"title", "type", b"type"]) -> None: ...

global___ExtLbs = ExtLbs

@typing_extensions.final
class GetUidByNameReq(google.protobuf.message.Message):
    """根据name取uid-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMES_FIELD_NUMBER: builtins.int
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """查询昵称列表"""
    def __init__(
        self,
        *,
        names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["names", b"names"]) -> None: ...

global___GetUidByNameReq = GetUidByNameReq

@typing_extensions.final
class GetUidByNameRsp(google.protobuf.message.Message):
    """根据name取uid-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UidsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    UIDS_FIELD_NUMBER: builtins.int
    @property
    def uids(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """k:昵称 v:mid"""
    def __init__(
        self,
        *,
        uids: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["uids", b"uids"]) -> None: ...

global___GetUidByNameRsp = GetUidByNameRsp

@typing_extensions.final
class GoodsContent(google.protobuf.message.Message):
    """发布时附带的商品卡的详细内容"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    SHOP_ID_FIELD_NUMBER: builtins.int
    source_type: builtins.int
    """商品类型
    1淘宝、2会员购
    """
    item_id: builtins.int
    """商品的id"""
    shop_id: builtins.int
    """店铺的id，兼容老版本"""
    def __init__(
        self,
        *,
        source_type: builtins.int = ...,
        item_id: builtins.int = ...,
        shop_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_id", b"item_id", "shop_id", b"shop_id", "source_type", b"source_type"]) -> None: ...

global___GoodsContent = GoodsContent

@typing_extensions.final
class LaunchedActivity(google.protobuf.message.Message):
    """UP已经创建的活动列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODULE_TITLE_FIELD_NUMBER: builtins.int
    ACTIVITIES_FIELD_NUMBER: builtins.int
    SHOW_MORE_FIELD_NUMBER: builtins.int
    module_title: builtins.str
    """模块名称，示例："已创建的活动" """
    @property
    def activities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchedActivityItem]:
        """已创建的活动列表"""
    @property
    def show_more(self) -> global___ShowMoreLaunchedActivity:
        """展示更多按钮
        已创建活动大于5个时下发
        """
    def __init__(
        self,
        *,
        module_title: builtins.str = ...,
        activities: collections.abc.Iterable[global___LaunchedActivityItem] | None = ...,
        show_more: global___ShowMoreLaunchedActivity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["show_more", b"show_more"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activities", b"activities", "module_title", b"module_title", "show_more", b"show_more"]) -> None: ...

global___LaunchedActivity = LaunchedActivity

@typing_extensions.final
class LaunchedActivityItem(google.protobuf.message.Message):
    """UP已经创建的活动详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_NAME_FIELD_NUMBER: builtins.int
    ACTIVITY_STATE_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """活动id"""
    activity_name: builtins.str
    """活动名称"""
    activity_state: builtins.int
    """活动是否已上线
    0未上线 1已上线
    """
    def __init__(
        self,
        *,
        activity_id: builtins.int = ...,
        activity_name: builtins.str = ...,
        activity_state: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "activity_name", b"activity_name", "activity_state", b"activity_state"]) -> None: ...

global___LaunchedActivityItem = LaunchedActivityItem

@typing_extensions.final
class LbsLoc(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    lat: builtins.float
    """经度"""
    lng: builtins.float
    """纬度"""
    def __init__(
        self,
        *,
        lat: builtins.float = ...,
        lng: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lat", b"lat", "lng", b"lng"]) -> None: ...

global___LbsLoc = LbsLoc

@typing_extensions.final
class MetaDataCtrl(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLATFORM_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TRACE_ID_FIELD_NUMBER: builtins.int
    TEENAGER_MODE_FIELD_NUMBER: builtins.int
    COLD_START_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    platform: builtins.str
    """客户端平台"""
    build: builtins.str
    """客户端build号"""
    mobi_app: builtins.str
    """客户端移动设备类型"""
    buvid: builtins.str
    """客户端buvid"""
    device: builtins.str
    """用户设备信息"""
    from_spmid: builtins.str
    """请求来源页面的spmid"""
    trace_id: builtins.str
    """请求的trace_id"""
    teenager_mode: builtins.int
    """青少年模式"""
    cold_start: builtins.int
    """0:正常 1:冷启动"""
    version: builtins.str
    """客户端版本号"""
    network: builtins.int
    """网络状态
    Unknown=0 WIFI=1 WWAN=2
    """
    ip: builtins.str
    """用户ip地址"""
    def __init__(
        self,
        *,
        platform: builtins.str = ...,
        build: builtins.str = ...,
        mobi_app: builtins.str = ...,
        buvid: builtins.str = ...,
        device: builtins.str = ...,
        from_spmid: builtins.str = ...,
        trace_id: builtins.str = ...,
        teenager_mode: builtins.int = ...,
        cold_start: builtins.int = ...,
        version: builtins.str = ...,
        network: builtins.int = ...,
        ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build", "buvid", b"buvid", "cold_start", b"cold_start", "device", b"device", "from", b"from", "from_spmid", b"from_spmid", "ip", b"ip", "mobi_app", b"mobi_app", "network", b"network", "platform", b"platform", "teenager_mode", b"teenager_mode", "trace_id", b"trace_id", "version", b"version"]) -> None: ...

global___MetaDataCtrl = MetaDataCtrl

@typing_extensions.final
class PlusRedDot(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLUS_HAS_RED_DOT_FIELD_NUMBER: builtins.int
    plus_has_red_dot: builtins.int
    """"""
    def __init__(
        self,
        *,
        plus_has_red_dot: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["plus_has_red_dot", b"plus_has_red_dot"]) -> None: ...

global___PlusRedDot = PlusRedDot

@typing_extensions.final
class Program(google.protobuf.message.Message):
    """小程序内容定义"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    PROGRAM_TEXT_FIELD_NUMBER: builtins.int
    JUMP_TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    desc: builtins.str
    """描述文字"""
    cover: builtins.str
    """封面图"""
    target_url: builtins.str
    """跳转链接"""
    icon: builtins.str
    """小程序icon"""
    program_text: builtins.str
    """小程序名称"""
    jump_text: builtins.str
    """跳转链接文案，如：去看看"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        cover: builtins.str = ...,
        target_url: builtins.str = ...,
        icon: builtins.str = ...,
        program_text: builtins.str = ...,
        jump_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "desc", b"desc", "icon", b"icon", "jump_text", b"jump_text", "program_text", b"program_text", "target_url", b"target_url", "title", b"title"]) -> None: ...

global___Program = Program

@typing_extensions.final
class PublishSetting(google.protobuf.message.Message):
    """发布相关的设置项"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_WORDS_TO_ARTICLE_FIELD_NUMBER: builtins.int
    MAX_WORDS_TO_ARTICLE_FIELD_NUMBER: builtins.int
    UPLOAD_SIZE_FIELD_NUMBER: builtins.int
    min_words_to_article: builtins.int
    """提示转为专栏的最小字数，使用utf-16编码计算字符数"""
    max_words_to_article: builtins.int
    """提示转为专栏的最大字数，使用utf-16编码计算字符数"""
    upload_size: builtins.int
    """gif上传的最大值，单位：MB"""
    def __init__(
        self,
        *,
        min_words_to_article: builtins.int = ...,
        max_words_to_article: builtins.int = ...,
        upload_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_words_to_article", b"max_words_to_article", "min_words_to_article", b"min_words_to_article", "upload_size", b"upload_size"]) -> None: ...

global___PublishSetting = PublishSetting

@typing_extensions.final
class PublishYellowBar(google.protobuf.message.Message):
    """发布页小黄条"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    text: builtins.str
    """展示文案"""
    url: builtins.str
    """跳转链接"""
    icon: builtins.str
    """展示图标"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        url: builtins.str = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "text", b"text", "url", b"url"]) -> None: ...

global___PublishYellowBar = PublishYellowBar

@typing_extensions.final
class RepostInitCheck(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOST_SRC_FIELD_NUMBER: builtins.int
    SHARE_ID_FIELD_NUMBER: builtins.int
    SHARE_MODE_FIELD_NUMBER: builtins.int
    @property
    def repost_src(self) -> global___DynIdentity:
        """"""
    share_id: builtins.str
    """"""
    share_mode: builtins.int
    """"""
    def __init__(
        self,
        *,
        repost_src: global___DynIdentity | None = ...,
        share_id: builtins.str = ...,
        share_mode: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repost_src", b"repost_src"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["repost_src", b"repost_src", "share_id", b"share_id", "share_mode", b"share_mode"]) -> None: ...

global___RepostInitCheck = RepostInitCheck

@typing_extensions.final
class ShareChannel(google.protobuf.message.Message):
    """分享渠道信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_ORIGIN_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    SHARE_CHANNELS_FIELD_NUMBER: builtins.int
    share_origin: builtins.str
    """业务类型，如动态是"dynamic" """
    oid: builtins.str
    """业务资源id"""
    sid: builtins.str
    """辅助id, 非必返回字段"""
    @property
    def share_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareChannelItem]:
        """渠道列表"""
    def __init__(
        self,
        *,
        share_origin: builtins.str = ...,
        oid: builtins.str = ...,
        sid: builtins.str = ...,
        share_channels: collections.abc.Iterable[global___ShareChannelItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "share_channels", b"share_channels", "share_origin", b"share_origin", "sid", b"sid"]) -> None: ...

global___ShareChannel = ShareChannel

@typing_extensions.final
class ShareChannelItem(google.protobuf.message.Message):
    """渠道"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PICTURE_FIELD_NUMBER: builtins.int
    SHARE_CHANNEL_FIELD_NUMBER: builtins.int
    RESERVE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """展示文案"""
    picture: builtins.str
    """展示图标"""
    share_channel: builtins.str
    """渠道名称"""
    @property
    def reserve(self) -> global___ShareReserve:
        """预约卡分享图信息，仅分享有预约信息的动态时存在"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        picture: builtins.str = ...,
        share_channel: builtins.str = ...,
        reserve: global___ShareReserve | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reserve", b"reserve"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "picture", b"picture", "reserve", b"reserve", "share_channel", b"share_channel"]) -> None: ...

global___ShareChannelItem = ShareChannelItem

@typing_extensions.final
class ShareReserve(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    QR_CODE_ICON_FIELD_NUMBER: builtins.int
    QR_CODE_TEXT_FIELD_NUMBER: builtins.int
    QR_CODE_URL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    POSTER_FIELD_NUMBER: builtins.int
    RESERVE_LOTTERY_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    desc: builtins.str
    """描述（时间+类型）"""
    qr_code_icon: builtins.str
    """二维码附带icon"""
    qr_code_text: builtins.str
    """二维码附带文本"""
    qr_code_url: builtins.str
    """二维码链接"""
    name: builtins.str
    """"""
    face: builtins.str
    """"""
    @property
    def poster(self) -> global___ShareReservePoster:
        """"""
    @property
    def reserve_lottery(self) -> global___ShareReserveLottery:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        qr_code_icon: builtins.str = ...,
        qr_code_text: builtins.str = ...,
        qr_code_url: builtins.str = ...,
        name: builtins.str = ...,
        face: builtins.str = ...,
        poster: global___ShareReservePoster | None = ...,
        reserve_lottery: global___ShareReserveLottery | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["poster", b"poster", "reserve_lottery", b"reserve_lottery"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "face", b"face", "name", b"name", "poster", b"poster", "qr_code_icon", b"qr_code_icon", "qr_code_text", b"qr_code_text", "qr_code_url", b"qr_code_url", "reserve_lottery", b"reserve_lottery", "title", b"title"]) -> None: ...

global___ShareReserve = ShareReserve

@typing_extensions.final
class ShareReserveLottery(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICON_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    icon: builtins.str
    """"""
    text: builtins.str
    """"""
    def __init__(
        self,
        *,
        icon: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "text", b"text"]) -> None: ...

global___ShareReserveLottery = ShareReserveLottery

@typing_extensions.final
class ShareReservePoster(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    url: builtins.str
    """"""
    width: builtins.float
    """"""
    height: builtins.float
    """"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        width: builtins.float = ...,
        height: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "url", b"url", "width", b"width"]) -> None: ...

global___ShareReservePoster = ShareReservePoster

@typing_extensions.final
class ShareResult(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_ENABLE_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    share_enable: builtins.int
    """"""
    toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        share_enable: builtins.int = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_enable", b"share_enable", "toast", b"toast"]) -> None: ...

global___ShareResult = ShareResult

@typing_extensions.final
class ShowMoreLaunchedActivity(google.protobuf.message.Message):
    """UP已经创建的活动列表中的展示更多按钮详情"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUTTON_TEXT_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    button_text: builtins.str
    """按钮的文案"""
    jump_url: builtins.str
    """按钮的跳转链接"""
    def __init__(
        self,
        *,
        button_text: builtins.str = ...,
        jump_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["button_text", b"button_text", "jump_url", b"jump_url"]) -> None: ...

global___ShowMoreLaunchedActivity = ShowMoreLaunchedActivity

@typing_extensions.final
class Sketch(google.protobuf.message.Message):
    """通用模板的网页元内容(sketch结构)定义"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    DESC_TEXT_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    COVER_URL_FIELD_NUMBER: builtins.int
    TARGET_URL_FIELD_NUMBER: builtins.int
    title: builtins.str
    """元内容标题，长度30限制"""
    desc_text: builtins.str
    """描述文字（文本内容第二行），长度233限制"""
    text: builtins.str
    """文本文字（文本内容第三行），仅限竖图通用卡片使用，长度233限制"""
    biz_id: builtins.int
    """表示业务方的id表示，对于在业务方有唯一标示的必填"""
    biz_type: builtins.int
    """业务类型，与展示时的右上角标有关，需要业务方向动态申请"""
    cover_url: builtins.str
    """封面图片链接地址，域名需要符合白名单"""
    target_url: builtins.str
    """跳转链接地址，域名需要符合白名单"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        desc_text: builtins.str = ...,
        text: builtins.str = ...,
        biz_id: builtins.int = ...,
        biz_type: builtins.int = ...,
        cover_url: builtins.str = ...,
        target_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "biz_type", b"biz_type", "cover_url", b"cover_url", "desc_text", b"desc_text", "target_url", b"target_url", "text", b"text", "title", b"title"]) -> None: ...

global___Sketch = Sketch

@typing_extensions.final
class UpPermission(google.protobuf.message.Message):
    """发布相关的权限内容"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEMS_FIELD_NUMBER: builtins.int
    LAUNCHED_ACTIVITY_FIELD_NUMBER: builtins.int
    SHARE_RESULT_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpPermissionItem]:
        """通用权限列表"""
    @property
    def launched_activity(self) -> global___LaunchedActivity:
        """已经创建的活动列表"""
    @property
    def share_result(self) -> global___ShareResult:
        """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___UpPermissionItem] | None = ...,
        launched_activity: global___LaunchedActivity | None = ...,
        share_result: global___ShareResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["launched_activity", b"launched_activity", "share_result", b"share_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "launched_activity", b"launched_activity", "share_result", b"share_result"]) -> None: ...

global___UpPermission = UpPermission

@typing_extensions.final
class UpPermissionItem(google.protobuf.message.Message):
    """通用发布权限内容的详细定义"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    HAS_RED_DOT_FIELD_NUMBER: builtins.int
    type: builtins.int
    """类型，enum UpPermissionType"""
    permission: builtins.int
    """UP是否有权限
    1-有，2-限制（展示但不可点，仅预约使用）
    """
    title: builtins.str
    """按钮文案"""
    subtitle: builtins.str
    """功能开关的副标题"""
    icon: builtins.str
    """按钮图标的url地址"""
    jump_url: builtins.str
    """跳转链接，permission=1时点击按钮跳到此链接"""
    toast: builtins.str
    """错误提示，permission=2时点击按钮会弹出此提示，目前仅预约使用"""
    has_red_dot: builtins.int
    """"""
    def __init__(
        self,
        *,
        type: builtins.int = ...,
        permission: builtins.int = ...,
        title: builtins.str = ...,
        subtitle: builtins.str = ...,
        icon: builtins.str = ...,
        jump_url: builtins.str = ...,
        toast: builtins.str = ...,
        has_red_dot: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_red_dot", b"has_red_dot", "icon", b"icon", "jump_url", b"jump_url", "permission", b"permission", "subtitle", b"subtitle", "title", b"title", "toast", b"toast", "type", b"type"]) -> None: ...

global___UpPermissionItem = UpPermissionItem

@typing_extensions.final
class UserCreateMeta(google.protobuf.message.Message):
    """用户主动发布（app/web发布）时的meta信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_META_FIELD_NUMBER: builtins.int
    LOC_FIELD_NUMBER: builtins.int
    REPOST_MODE_FIELD_NUMBER: builtins.int
    @property
    def app_meta(self) -> global___MetaDataCtrl:
        """用户发布客户端的meta信息"""
    @property
    def loc(self) -> global___LbsLoc:
        """用户发布时的位置信息（经纬度）"""
    repost_mode: builtins.int
    """1-发布页转发 2-立即转发"""
    def __init__(
        self,
        *,
        app_meta: global___MetaDataCtrl | None = ...,
        loc: global___LbsLoc | None = ...,
        repost_mode: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_meta", b"app_meta", "loc", b"loc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_meta", b"app_meta", "loc", b"loc", "repost_mode", b"repost_mode"]) -> None: ...

global___UserCreateMeta = UserCreateMeta

@typing_extensions.final
class VideoShareInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    PART_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """"""
    part: builtins.int
    """"""
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
        part: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "part", b"part"]) -> None: ...

global___VideoShareInfo = VideoShareInfo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TopPhotoType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TopPhotoTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TopPhotoType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _TopPhotoType.ValueType  # 0
    """"""
    PIC: _TopPhotoType.ValueType  # 1
    """"""
    ARCHIVE: _TopPhotoType.ValueType  # 2
    """"""

class TopPhotoType(_TopPhotoType, metaclass=_TopPhotoTypeEnumTypeWrapper):
    """"""

UNKNOWN: TopPhotoType.ValueType  # 0
""""""
PIC: TopPhotoType.ValueType  # 1
""""""
ARCHIVE: TopPhotoType.ValueType  # 2
""""""
global___TopPhotoType = TopPhotoType

@typing_extensions.final
class NoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoReply = NoReply

@typing_extensions.final
class OfficialReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    RCMD_FIELD_NUMBER: builtins.int
    IOS_URL_FIELD_NUMBER: builtins.int
    ANDROID_URL_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    uid: builtins.int
    """"""
    name: builtins.str
    """"""
    icon: builtins.str
    """"""
    scheme: builtins.str
    """"""
    rcmd: builtins.str
    """"""
    ios_url: builtins.str
    """"""
    android_url: builtins.str
    """"""
    button: builtins.str
    """"""
    deleted: builtins.str
    """"""
    mtime: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        uid: builtins.int = ...,
        name: builtins.str = ...,
        icon: builtins.str = ...,
        scheme: builtins.str = ...,
        rcmd: builtins.str = ...,
        ios_url: builtins.str = ...,
        android_url: builtins.str = ...,
        button: builtins.str = ...,
        deleted: builtins.str = ...,
        mtime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["android_url", b"android_url", "button", b"button", "deleted", b"deleted", "icon", b"icon", "id", b"id", "ios_url", b"ios_url", "mtime", b"mtime", "name", b"name", "rcmd", b"rcmd", "scheme", b"scheme", "uid", b"uid"]) -> None: ...

global___OfficialReply = OfficialReply

@typing_extensions.final
class OfficialRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___OfficialRequest = OfficialRequest

@typing_extensions.final
class PhotoMall(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    NIGHT_IMG_FIELD_NUMBER: builtins.int
    IS_ACTIVATED_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    name: builtins.str
    """"""
    img: builtins.str
    """"""
    night_img: builtins.str
    """"""
    is_activated: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        name: builtins.str = ...,
        img: builtins.str = ...,
        night_img: builtins.str = ...,
        is_activated: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "img", b"img", "is_activated", b"is_activated", "name", b"name", "night_img", b"night_img"]) -> None: ...

global___PhotoMall = PhotoMall

@typing_extensions.final
class PhotoMallListReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PhotoMall]:
        """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[global___PhotoMall] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list"]) -> None: ...

global___PhotoMallListReply = PhotoMallListReply

@typing_extensions.final
class PhotoMallListReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOBIAPP_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    mobiapp: builtins.str
    """"""
    mid: builtins.int
    """"""
    device: builtins.str
    """"""
    def __init__(
        self,
        *,
        mobiapp: builtins.str = ...,
        mid: builtins.int = ...,
        device: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device", b"device", "mid", b"mid", "mobiapp", b"mobiapp"]) -> None: ...

global___PhotoMallListReq = PhotoMallListReq

@typing_extensions.final
class PrivacyReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PrivacyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRIVACY_FIELD_NUMBER: builtins.int
    @property
    def privacy(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """"""
    def __init__(
        self,
        *,
        privacy: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["privacy", b"privacy"]) -> None: ...

global___PrivacyReply = PrivacyReply

@typing_extensions.final
class PrivacyRequest(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___PrivacyRequest = PrivacyRequest

@typing_extensions.final
class SetTopPhotoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOBIAPP_FIELD_NUMBER: builtins.int
    I_D_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    mobiapp: builtins.str
    """"""
    i_d: builtins.int
    """"""
    mid: builtins.int
    """"""
    type: builtins.int
    """"""
    def __init__(
        self,
        *,
        mobiapp: builtins.str = ...,
        i_d: builtins.int = ...,
        mid: builtins.int = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["i_d", b"i_d", "mid", b"mid", "mobiapp", b"mobiapp", "type", b"type"]) -> None: ...

global___SetTopPhotoReq = SetTopPhotoReq

@typing_extensions.final
class SpaceSettingReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_FIELD_NUMBER: builtins.int
    FAV_VIDEO_FIELD_NUMBER: builtins.int
    COINS_VIDEO_FIELD_NUMBER: builtins.int
    LIKES_VIDEO_FIELD_NUMBER: builtins.int
    BANGUMI_FIELD_NUMBER: builtins.int
    PLAYED_GAME_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    COMIC_FIELD_NUMBER: builtins.int
    B_BQ_FIELD_NUMBER: builtins.int
    DRESS_UP_FIELD_NUMBER: builtins.int
    DISABLE_FOLLOWING_FIELD_NUMBER: builtins.int
    LIVE_PLAYBACK_FIELD_NUMBER: builtins.int
    CLOSE_SPACE_MEDAL_FIELD_NUMBER: builtins.int
    ONLY_SHOW_WEARING_FIELD_NUMBER: builtins.int
    DISABLE_SHOW_SCHOOL_FIELD_NUMBER: builtins.int
    DISABLE_SHOW_NFT_FIELD_NUMBER: builtins.int
    channel: builtins.int
    """"""
    fav_video: builtins.int
    """"""
    coins_video: builtins.int
    """"""
    likes_video: builtins.int
    """"""
    bangumi: builtins.int
    """"""
    played_game: builtins.int
    """"""
    groups: builtins.int
    """"""
    comic: builtins.int
    """"""
    b_bq: builtins.int
    """"""
    dress_up: builtins.int
    """"""
    disable_following: builtins.int
    """"""
    live_playback: builtins.int
    """"""
    close_space_medal: builtins.int
    """"""
    only_show_wearing: builtins.int
    """"""
    disable_show_school: builtins.int
    """"""
    disable_show_nft: builtins.int
    """"""
    def __init__(
        self,
        *,
        channel: builtins.int = ...,
        fav_video: builtins.int = ...,
        coins_video: builtins.int = ...,
        likes_video: builtins.int = ...,
        bangumi: builtins.int = ...,
        played_game: builtins.int = ...,
        groups: builtins.int = ...,
        comic: builtins.int = ...,
        b_bq: builtins.int = ...,
        dress_up: builtins.int = ...,
        disable_following: builtins.int = ...,
        live_playback: builtins.int = ...,
        close_space_medal: builtins.int = ...,
        only_show_wearing: builtins.int = ...,
        disable_show_school: builtins.int = ...,
        disable_show_nft: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["b_bq", b"b_bq", "bangumi", b"bangumi", "channel", b"channel", "close_space_medal", b"close_space_medal", "coins_video", b"coins_video", "comic", b"comic", "disable_following", b"disable_following", "disable_show_nft", b"disable_show_nft", "disable_show_school", b"disable_show_school", "dress_up", b"dress_up", "fav_video", b"fav_video", "groups", b"groups", "likes_video", b"likes_video", "live_playback", b"live_playback", "only_show_wearing", b"only_show_wearing", "played_game", b"played_game"]) -> None: ...

global___SpaceSettingReply = SpaceSettingReply

@typing_extensions.final
class SpaceSettingReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___SpaceSettingReq = SpaceSettingReq

@typing_extensions.final
class TopPhoto(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMG_URL_FIELD_NUMBER: builtins.int
    NIGHT_IMG_URL_FIELD_NUMBER: builtins.int
    SID_FIELD_NUMBER: builtins.int
    img_url: builtins.str
    """"""
    night_img_url: builtins.str
    """"""
    sid: builtins.int
    """"""
    def __init__(
        self,
        *,
        img_url: builtins.str = ...,
        night_img_url: builtins.str = ...,
        sid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["img_url", b"img_url", "night_img_url", b"night_img_url", "sid", b"sid"]) -> None: ...

global___TopPhoto = TopPhoto

@typing_extensions.final
class TopPhotoArc(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    PIC_FIELD_NUMBER: builtins.int
    show: builtins.bool
    """"""
    aid: builtins.int
    """"""
    pic: builtins.str
    """"""
    def __init__(
        self,
        *,
        show: builtins.bool = ...,
        aid: builtins.int = ...,
        pic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "pic", b"pic", "show", b"show"]) -> None: ...

global___TopPhotoArc = TopPhotoArc

@typing_extensions.final
class TopPhotoArcCancelReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___TopPhotoArcCancelReq = TopPhotoArcCancelReq

@typing_extensions.final
class TopPhotoReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_PHOTO_FIELD_NUMBER: builtins.int
    TOP_PHOTO_ARC_FIELD_NUMBER: builtins.int
    @property
    def top_photo(self) -> global___TopPhoto:
        """"""
    @property
    def top_photo_arc(self) -> global___TopPhotoArc:
        """"""
    def __init__(
        self,
        *,
        top_photo: global___TopPhoto | None = ...,
        top_photo_arc: global___TopPhotoArc | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["top_photo", b"top_photo", "top_photo_arc", b"top_photo_arc"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["top_photo", b"top_photo", "top_photo_arc", b"top_photo_arc"]) -> None: ...

global___TopPhotoReply = TopPhotoReply

@typing_extensions.final
class TopPhotoReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOBIAPP_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOGIN_MID_FIELD_NUMBER: builtins.int
    mobiapp: builtins.str
    """"""
    mid: builtins.int
    """"""
    build: builtins.int
    """"""
    device: builtins.str
    """"""
    login_mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mobiapp: builtins.str = ...,
        mid: builtins.int = ...,
        build: builtins.int = ...,
        device: builtins.str = ...,
        login_mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build", "device", b"device", "login_mid", b"login_mid", "mid", b"mid", "mobiapp", b"mobiapp"]) -> None: ...

global___TopPhotoReq = TopPhotoReq

@typing_extensions.final
class UpActivityTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TAB_CONT_FIELD_NUMBER: builtins.int
    TAB_NAME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    state: builtins.int
    """"""
    tab_cont: builtins.int
    """"""
    tab_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        state: builtins.int = ...,
        tab_cont: builtins.int = ...,
        tab_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "state", b"state", "tab_cont", b"tab_cont", "tab_name", b"tab_name"]) -> None: ...

global___UpActivityTabReq = UpActivityTabReq

@typing_extensions.final
class UpActivityTabResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["success", b"success"]) -> None: ...

global___UpActivityTabResp = UpActivityTabResp

@typing_extensions.final
class UpRcmdBlackListReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpRcmdBlackListReply = UpRcmdBlackListReply

@typing_extensions.final
class UserTabReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAB_TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    TAB_NAME_FIELD_NUMBER: builtins.int
    TAB_ORDER_FIELD_NUMBER: builtins.int
    TAB_CONT_FIELD_NUMBER: builtins.int
    IS_DEFAULT_FIELD_NUMBER: builtins.int
    H5_LINK_FIELD_NUMBER: builtins.int
    tab_type: builtins.int
    """"""
    mid: builtins.int
    """"""
    tab_name: builtins.str
    """"""
    tab_order: builtins.int
    """"""
    tab_cont: builtins.int
    """"""
    is_default: builtins.int
    """"""
    h5_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        tab_type: builtins.int = ...,
        mid: builtins.int = ...,
        tab_name: builtins.str = ...,
        tab_order: builtins.int = ...,
        tab_cont: builtins.int = ...,
        is_default: builtins.int = ...,
        h5_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["h5_link", b"h5_link", "is_default", b"is_default", "mid", b"mid", "tab_cont", b"tab_cont", "tab_name", b"tab_name", "tab_order", b"tab_order", "tab_type", b"tab_type"]) -> None: ...

global___UserTabReply = UserTabReply

@typing_extensions.final
class UserTabReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    PLAT_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    plat: builtins.int
    """"""
    build: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        plat: builtins.int = ...,
        build: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build", b"build", "mid", b"mid", "plat", b"plat"]) -> None: ...

global___UserTabReq = UserTabReq

@typing_extensions.final
class WhitelistAddReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADD_OK_FIELD_NUMBER: builtins.int
    add_ok: builtins.bool
    """"""
    def __init__(
        self,
        *,
        add_ok: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["add_ok", b"add_ok"]) -> None: ...

global___WhitelistAddReply = WhitelistAddReply

@typing_extensions.final
class WhitelistAddReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    ETIME_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    stime: builtins.int
    """"""
    etime: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        stime: builtins.int = ...,
        etime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["etime", b"etime", "mid", b"mid", "stime", b"stime"]) -> None: ...

global___WhitelistAddReq = WhitelistAddReq

@typing_extensions.final
class WhitelistReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_WHITE_FIELD_NUMBER: builtins.int
    is_white: builtins.bool
    """"""
    def __init__(
        self,
        *,
        is_white: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_white", b"is_white"]) -> None: ...

global___WhitelistReply = WhitelistReply

@typing_extensions.final
class WhitelistReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid"]) -> None: ...

global___WhitelistReq = WhitelistReq

@typing_extensions.final
class WhitelistUpReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UP_OK_FIELD_NUMBER: builtins.int
    up_ok: builtins.bool
    """"""
    def __init__(
        self,
        *,
        up_ok: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["up_ok", b"up_ok"]) -> None: ...

global___WhitelistUpReply = WhitelistUpReply

@typing_extensions.final
class WhitelistValidTimeReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_WHITE_FIELD_NUMBER: builtins.int
    STIME_FIELD_NUMBER: builtins.int
    ETIME_FIELD_NUMBER: builtins.int
    is_white: builtins.bool
    """"""
    stime: builtins.int
    """"""
    etime: builtins.int
    """"""
    def __init__(
        self,
        *,
        is_white: builtins.bool = ...,
        stime: builtins.int = ...,
        etime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["etime", b"etime", "is_white", b"is_white", "stime", b"stime"]) -> None: ...

global___WhitelistValidTimeReply = WhitelistValidTimeReply



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.pangu.gallery.v1 import gallery_pb2 as bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class GalleryInterfaceStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/Ping',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UserInfo = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/UserInfo',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReply.FromString,
                )
        self.ListNFTByMid = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/ListNFTByMid',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReply.FromString,
                )
        self.ListOrderByMid = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/ListOrderByMid',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReply.FromString,
                )
        self.BasicInfo = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/BasicInfo',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReply.FromString,
                )
        self.UserCheck = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/UserCheck',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReply.FromString,
                )
        self.AgreePolicy = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/AgreePolicy',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReply.FromString,
                )
        self.GetLastPolicy = channel.unary_unary(
                '/bilibili.pangu.gallery.v1.GalleryInterface/GetLastPolicy',
                request_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReq.SerializeToString,
                response_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReply.FromString,
                )


class GalleryInterfaceServicer(object):
    """
    """

    def Ping(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserInfo(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNFTByMid(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrderByMid(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BasicInfo(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserCheck(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AgreePolicy(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLastPolicy(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GalleryInterfaceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UserInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.UserInfo,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReply.SerializeToString,
            ),
            'ListNFTByMid': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNFTByMid,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReply.SerializeToString,
            ),
            'ListOrderByMid': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrderByMid,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReply.SerializeToString,
            ),
            'BasicInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.BasicInfo,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReply.SerializeToString,
            ),
            'UserCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.UserCheck,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReply.SerializeToString,
            ),
            'AgreePolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.AgreePolicy,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReply.SerializeToString,
            ),
            'GetLastPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLastPolicy,
                    request_deserializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReq.FromString,
                    response_serializer=bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.pangu.gallery.v1.GalleryInterface', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GalleryInterface(object):
    """
    """

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/Ping',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/UserInfo',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetUserInfoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNFTByMid(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/ListNFTByMid',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListNFTByMidReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrderByMid(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/ListOrderByMid',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.ListOrderByMidReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BasicInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/BasicInfo',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.BasicInfoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/UserCheck',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.UserCheckReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AgreePolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/AgreePolicy',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.AgreePolicyReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLastPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.pangu.gallery.v1.GalleryInterface/GetLastPolicy',
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReq.SerializeToString,
            bilibili_dot_pangu_dot_gallery_dot_v1_dot_gallery__pb2.GetLastPolicyReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QoeReportReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CANCEL_FIELD_NUMBER: builtins.int
    BUSINESS_TYPE_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    SCORE_RESULT_FIELD_NUMBER: builtins.int
    BUSINESS_DATA_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    scene: builtins.int
    """"""
    type: builtins.int
    """"""
    cancel: builtins.bool
    """"""
    business_type: builtins.str
    """"""
    oid: builtins.int
    """"""
    @property
    def score_result(self) -> global___QoeScoreResult:
        """"""
    business_data: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        scene: builtins.int = ...,
        type: builtins.int = ...,
        cancel: builtins.bool = ...,
        business_type: builtins.str = ...,
        oid: builtins.int = ...,
        score_result: global___QoeScoreResult | None = ...,
        business_data: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["score_result", b"score_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business_data", b"business_data", "business_type", b"business_type", "cancel", b"cancel", "id", b"id", "oid", b"oid", "scene", b"scene", "score_result", b"score_result", "type", b"type"]) -> None: ...

global___QoeReportReq = QoeReportReq

@typing_extensions.final
class QoeScoreResult(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_FIELD_NUMBER: builtins.int
    score: builtins.float
    """"""
    def __init__(
        self,
        *,
        score: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["score", b"score"]) -> None: ...

global___QoeScoreResult = QoeScoreResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Metadata(google.protobuf.message.Message):
    """请求元数据
    gRPC头部:x-bili-metadata-bin
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    access_key: builtins.str
    """登录Token"""
    mobi_app: builtins.str
    """包类型"""
    device: builtins.str
    """运行设备"""
    build: builtins.int
    """构建id"""
    channel: builtins.str
    """APP分发渠道"""
    buvid: builtins.str
    """设备buvid"""
    platform: builtins.str
    """平台类型"""
    def __init__(
        self,
        *,
        access_key: builtins.str = ...,
        mobi_app: builtins.str = ...,
        device: builtins.str = ...,
        build: builtins.int = ...,
        channel: builtins.str = ...,
        buvid: builtins.str = ...,
        platform: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "build", b"build", "buvid", b"buvid", "channel", b"channel", "device", b"device", "mobi_app", b"mobi_app", "platform", b"platform"]) -> None: ...

global___Metadata = Metadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/pangu/gallery/v1/openplatform/apiserver/v1alpha1/api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCbilibili/pangu/gallery/v1/openplatform/apiserver/v1alpha1/api.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.pangu.gallery.v1.openplatform.apiserver.v1alpha1.api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
